==> pycate-0.1.5.tar.gz: pycate-0.1.5/pycate/model/info_model.py <==
# -*- coding:utf-8 -*-

import pymongo

import config

from config import cfg as c


class MInfo(object):
    def __init__(self, sig):
        con = pymongo.MongoClient('localhost')
        self.db = con[config.mongo['dbname']]
        self.db.authenticate(config.mongo['dbuser'], config.mongo['dbpass'])
        self.tab_info = self.db[sig]

    def __disable_sig__(self, def_uid, sig):
        '''
        取消某字段的真值，变为假值
        '''
        self.tab_info.update({'def_uid': def_uid}, {"$set": {sig: 0}})

    def query_by_tagname(self, tag_name):

        condition = { 'keywords': {'$elemMatch': { '$eq': tag_name} }}
        # condition = { }
        return self.tab_info.find(condition)


    def get_user_jianli(self, userid):
        condition = {'userid': userid,
                     'parentid': '0900',
                     'def_valid': 1,
                     'def_banned': 0}
        db_data = self.tab_info.find(condition)
        return (db_data)

    def set_valid(self, def_uid):
        '''
        将某消息设置为有效信息
        :param def_uid:
        :return:
        '''
        # tt = self.get_by_id(def_uid)
        # tt[sig] = 0

        # {"name": "mike"}, {"$set": {"active_time": "20130408120000"}}
        try:
            self.tab_info.update({'def_uid': def_uid},
                                 {"$set": {'def_valid': 1}})
            return True
        except:
            return False

    def dis_tuiguang(self, def_uid):
        self.__disable_sig__(def_uid, 'def_tuiguang')


    def update_view_count(self, def_uid):
        views_vka = self.get_by_id(def_uid)['views']
        self.tab_info.update({'def_uid': def_uid},
                             {"$set": {'views': views_vka + 1}})



    def dis_zhiding(self, def_uid):
        self.__disable_sig__(def_uid, 'def_zhiding')

    def dis_fresh(self, def_uid):
        self.__disable_sig__(def_uid, 'def_refresh')


    def delete_by_uid(self, def_uid):
        self.tab_info.remove({'def_uid': def_uid})

    def get_list_zhiding(self, condition):
        '''
        得到置顶的记录
        '''
        db_data_out = []
        # 排序顺序：置顶、推广、更新时间
        self.sort_condition = [('def_zhiding', pymongo.DESCENDING),
                               ('def_tuiguang', pymongo.DESCENDING),
                               ('def_update_time', pymongo.DESCENDING)
        ]
        # 选择算法，得到结果
        # 首先是置顶
        # 因为置顶是固定的，所以不计算置顶的。
        condition_zhiding = condition.copy()
        condition_zhiding['def_zhiding'] = 1
        db_data = self.tab_info.find(condition_zhiding).limit(2).skip(0).sort(
            [('def_zhiding_out_time', pymongo.DESCENDING)])
        for x in db_data:
            db_data_out.append(x)

        for x in db_data:
            db_data_out.append(x)
        return (db_data_out)

    def get_list(self, condition):
        db_data_out = []
        # 排序顺序：置顶、推广、更新时间
        self.sort_condition = [('def_zhiding', pymongo.DESCENDING),
                               ('def_tuiguang', pymongo.DESCENDING),
                               ('def_update_time', pymongo.DESCENDING)
        ]
        # 选择算法，得到结果
        # # 首先是置顶
        # 因为置顶是固定的，所以不计算置顶的。
        '''
        condition_zhiding = condition.copy()
        condition_zhiding['def_zhiding'] = 1
        db_data = self.minfo.find(condition_zhiding).sort([('def_zhiding_out_time', pymongo.DESCENDING)])
        for x in db_data:
            db_data_out.append(x)
        '''

        # 然后是推广
        condition_tuiguang = condition.copy()
        condition_tuiguang['def_tuiguang'] = 1
        condition_tuiguang['def_zhiding'] = 0
        db_data = self.tab_info.find(condition_tuiguang).sort([('def_tuiguang_out_time', pymongo.DESCENDING)])
        for x in db_data:
            db_data_out.append(x)

        # 然后是根据刷新来处理。
        condition_refresh = condition.copy()
        condition_refresh['def_refresh'] = 1
        condition_refresh['def_tuiguang'] = 0
        condition_refresh['def_zhiding'] = 0

        db_data = self.tab_info.find(condition_refresh).sort([('def_refresh_out_time', pymongo.DESCENDING)])
        for x in db_data:
            db_data_out.append(x)

        return (db_data_out)

    def get_list_fenye(self, condition, page_num):
        # 置顶
        zhiding_list = self.get_list_zhiding(condition)
        # 所有的记录
        all_list = self.get_list(condition)
        # 当前分页的记录
        current_list = all_list[(page_num - 1) * c.info_list_per_page: (page_num ) * c.info_list_per_page]
        return (zhiding_list + current_list)

    def get_cat_recs_count(self, catid):
        '''
        获取某一分类下的数目
        '''
        condition = {'catid': catid, 'def_valid': 1,
                     'def_banned': 0}
        condition["$or"] = [{'def_refresh': 1},
                            {'def_zhiding': 1},
                            {'def_tuiguang': 1}]
        db_data = self.tab_info.find(condition)
        return db_data.count()

    def get_by_id(self, input):
        return self.tab_info.find_one({'def_uid': input})

    def get_by_userid(self, input):
        return self.tab_info.find({'userid': input})

    def get_by_condition(self, input, limit_num = 20):
        return self.tab_info.find(input).limit(limit_num).sort([('def_refresh_out_time', pymongo.DESCENDING)])

    def get_num_condition(self, con):
        return self.tab_info.find(con).count()

    def insert_data(self, post_data):
        # 防止插入相同 UID的信息，
        # 需要先进行判断
        if self.get_by_id(post_data['def_uid']) is None:
            pass
        else:
            return False
        try:
            self.tab_info.save(post_data)
            return True
        except:
            return False


    def update(self, uid, post_data):
        try:
            self.tab_info.update({"def_uid": uid}, post_data)
            return True
        except:
            return False

    def delete(self, del_id):
        try:
            self.tab_info.remove({"def_uid": del_id})
            return True
        except:
            return False


    def clear_all(self):
        self.tab_info.remove()


if __name__ == '__main__':
    uu = MInfo('info')

    tt = uu.get_list( {'catid': '0303'} )
    for x in tt:
        x_new  = x
        x_new['extra_size'] = [0]
        x_new['extra_filetype'] = ['']
        uu.update( x['def_uid'], x_new)

==> pycate-0.1.6.tar.gz: pycate-0.1.6/pycate/model/info_model.py <==
# -*- coding:utf-8 -*-

import pymongo

import config

from config import cfg as c


class MInfo(object):
    def __init__(self, sig):
        con = pymongo.MongoClient('localhost')
        self.db = con[config.mongo['dbname']]
        self.db.authenticate(config.mongo['dbuser'], config.mongo['dbpass'])
        self.tab_info = self.db[sig]

    def __disable_sig__(self, def_uid, sig):
        '''
        取消某字段的真值，变为假值
        '''
        self.tab_info.update({'def_uid': def_uid}, {"$set": {sig: 0}})

    def query_by_tagname(self, tag_name):

        condition = {'keywords': {'$elemMatch': {'$eq': tag_name}}}

        return self.tab_info.find(condition)

    def get_user_jianli(self, userid):
        condition = {'userid': userid,
                     'parentid': '0900',
                     'def_valid': 1,
                     'def_banned': 0}
        db_data = self.tab_info.find(condition)
        return (db_data)

    def set_valid(self, def_uid):
        '''
        将某消息设置为有效信息
        '''
        try:
            self.tab_info.update({'def_uid': def_uid},
                                 {"$set": {'def_valid': 1}})
            return True
        except:
            return False

    def dis_tuiguang(self, def_uid):
        self.__disable_sig__(def_uid, 'def_tuiguang')

    def update_view_count(self, def_uid):
        views_vka = self.get_by_id(def_uid)['views']
        self.tab_info.update({'def_uid': def_uid},
                             {"$set": {'views': views_vka + 1}})

    def dis_zhiding(self, def_uid):
        self.__disable_sig__(def_uid, 'def_zhiding')

    def dis_fresh(self, def_uid):
        self.__disable_sig__(def_uid, 'def_refresh')

    def delete_by_uid(self, def_uid):
        self.tab_info.remove({'def_uid': def_uid})

    def get_list_zhiding(self, condition):
        '''
        得到置顶的记录
        '''
        db_data_out = []
        # 排序顺序：置顶、推广、更新时间
        self.sort_condition = [('def_zhiding', pymongo.DESCENDING),
                               ('def_tuiguang', pymongo.DESCENDING),
                               ('def_update_time', pymongo.DESCENDING)
                               ]
        # 选择算法，得到结果
        # 首先是置顶
        # 因为置顶是固定的，所以不计算置顶的。
        condition_zhiding = condition.copy()
        condition_zhiding['def_zhiding'] = 1
        db_data = self.tab_info.find(condition_zhiding).limit(2).skip(0).sort(
            [('def_zhiding_out_time', pymongo.DESCENDING)])
        for x in db_data:
            db_data_out.append(x)

        for x in db_data:
            db_data_out.append(x)
        return (db_data_out)

    def get_list(self, condition):
        db_data_out = []
        db_data = self.tab_info.find(condition)
        for x in db_data:
            db_data_out.append(x)

        return (db_data_out)

    def get_list_fenye(self, tag_slug, page_num):
        # 所有的记录
        all_list = self.get_list(tag_slug)
        # 当前分页的记录
        current_list = all_list[(page_num - 1) * c.info_list_per_page: (page_num) * c.info_list_per_page]
        return (current_list)

    def get_label_fenye(self, tag_slug, page_num):
        # 所有的记录
        all_list = self.query_by_tagname(tag_slug)
        # 当前分页的记录
        current_list = all_list[(page_num - 1) * c.info_list_per_page: (page_num) * c.info_list_per_page]
        return (current_list)

    def get_cat_recs_count(self, catid):
        '''
        获取某一分类下的数目
        '''
        condition = {'catid': catid, 'def_valid': 1, 'def_banned': 0}
        condition["$or"] = [{'def_refresh': 1},
                            {'def_zhiding': 1},
                            {'def_tuiguang': 1}]
        db_data = self.tab_info.find(condition)
        return db_data.count()

    def get_by_id(self, input):
        return self.tab_info.find_one({'def_uid': input})

    def get_by_userid(self, input):
        return self.tab_info.find({'userid': input})

    def get_by_condition(self, input, limit_num=20):
        return self.tab_info.find(input).limit(limit_num).sort([('def_refresh_out_time', pymongo.DESCENDING)])

    def get_num_condition(self, con):
        return self.tab_info.find(con).count()

    def insert_data(self, post_data):
        # 防止插入相同 UID的信息，
        # 需要先进行判断
        if self.get_by_id(post_data['def_uid']) is None:
            pass
        else:
            return False
        try:
            self.tab_info.save(post_data)
            return True
        except:
            return False

    def update(self, uid, post_data):
        try:
            self.tab_info.update({"def_uid": uid}, post_data)
            return True
        except:
            return False

    def delete(self, del_id):
        try:
            self.tab_info.remove({"def_uid": del_id})
            return True
        except:
            return False

    def clear_all(self):
        self.tab_info.remove()
